Release Notes
=============

.. note:: Contributors please include release notes as needed or appropriate with your bug fixes, feature additions and tests.

.. toctree::
  :maxdepth: 2

  5.1.0
  5.0.0
  4.3.0
  4.2.1
  4.2.0
  4.1.1
  4.1.0
  4.0.0
  3.4.0
  3.3.2
  3.3.0
  3.2.0
  3.1.2
  3.1.1
  3.1.0
  3.0.0
  2.8.0
  2.7.0
